## 1.0.0b1

* Fixes namespace handling by removing `minimal_names` concept. (#7)
* Analyzes egg-info dirs too. (#1)
* Now provides a CLI, so is installable by pickley.  (#6)


## 0.9.0

* Check static metadata instead of using requirements.txt, by default.
* Requirement patterns are relative to a detected project root, instead of cwd.


## 0.0.2

Add missing README content


## 0.0.1

Initial functional version
